@@ -3,16 +3,17 @@ WFO.remember <- function(
 )
 {
 
-    WFO.data.file <- paste(system.file(package="WorldFlora"), "/etc/remember.txt", sep="")    
+    WFO.data.file <- paste(system.file(package="WorldFlora"), "/etc/remember.txt", sep="")
+    WFO.data.file <- normalizePath(WFO.data.file)
 
     if (is.null(WFO.file) == FALSE) {
         data.save <- data.frame(WFO.file=file.path(WFO.file), date=date())
-        utils::write.table(data.save, file=WFO.data.file, quote=F, sep="\t", row.names=F, append=FALSE)
-        WFO.file1 <- file.path(WFO.file)
+        data.table::fwrite(data.save, file=WFO.data.file, sep="|", row.names=FALSE)
+        WFO.file1 <- normalizePath(file.path(WFO.file))
     }else{
         if (file.exists(WFO.data.file) == FALSE) {stop("Location of WFO data was not provided earlier")}
-        data.save <- utils::read.table(WFO.data.file, header=T, sep="\t")
-        WFO.file1 <- file.path(as.character(data.save$WFO.file))
+        data.save <- data.table::fread(WFO.data.file, sep="|")
+        WFO.file1 <- normalizePath(file.path(as.character(data.save$WFO.file)))
         cat(paste("Data sourced from: ", WFO.file1, " (", data.save$date, ")", "\n", sep=""))
     }
 
